# Generated by roxygen2: do not edit by hand

export(adaptive.t.test)
export(adjust.pvalues)
export(analyze.gene)
export(build.analysis.df)
export(classify.effect.size)
export(compute.ci)
export(compute.effect.size)
export(correlation.heatmap.plot)
export(extract.expression)
export(find.probe.by.gene)
export(fit.lasso)
export(flag.biological.relevance)
export(gene.analysis.plot)
export(gene.correlation.matrix)
export(get.gene.expression)
export(get.gene.name)
export(load.geo.soft)
export(nonparametric.test)
export(pca.plot)
export(run.gsea)
export(run.limma.de)
export(volcano.plot)
importFrom(stats,cor)
importFrom(stats,model.matrix)
importFrom(stats,na.omit)
importFrom(stats,oneway.test)
importFrom(stats,p.adjust)
importFrom(stats,prcomp)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,t.test)
importFrom(stats,var.test)
importFrom(stats,wilcox.test)
importFrom(utils,globalVariables)
importFrom(utils,head)
